==> chromium-browser_69.0.3497.81.orig.tar.xz: chromium-69.0.3497.81/ash/public/cpp/app_list/answer_card_contents_registry.h <==
// Copyright 2018 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef ASH_PUBLIC_CPP_APP_LIST_ANSWER_CARD_CONTENTS_REGISTRY_H_
#define ASH_PUBLIC_CPP_APP_LIST_ANSWER_CARD_CONTENTS_REGISTRY_H_

#include <map>

#include "ash/public/cpp/ash_public_export.h"
#include "base/macros.h"
#include "base/unguessable_token.h"

namespace views {
class View;
}

namespace app_list {

// Helper class to provide a token to answer card view map when app list UI code
// runs in the same process of answer card provider (classic ash, or mash before
// UI code is migrated to ash). In such environment, chrome creates and owns an
// instance of this class. AnswerCardContents registers answer card contents
// with it and get a token back. App list UI code gets the token and use it to
// look up the view to show. On mash after the UI code migration, this class
// will NOT be used at all. App list UI code would use the token to embed the
// answer card content directly.
class ASH_PUBLIC_EXPORT AnswerCardContentsRegistry {
 public:
  AnswerCardContentsRegistry();
  ~AnswerCardContentsRegistry();

  static AnswerCardContentsRegistry* Get();

  // Register content with a View.
  base::UnguessableToken Register(views::View* contents_view);

  // Unregister and release the associated resources.
  void Unregister(const base::UnguessableToken& token);

  // Get the view for the given token. Return nullptr for unknown token.
  views::View* GetView(const base::UnguessableToken& token);

 private:
  std::map<base::UnguessableToken, views::View*> contents_map_;

  DISALLOW_COPY_AND_ASSIGN(AnswerCardContentsRegistry);
};

}  // namespace app_list

#endif  // ASH_PUBLIC_CPP_APP_LIST_ANSWER_CARD_CONTENTS_REGISTRY_H_

==> chromium-browser_70.0.3538.110.orig.tar.xz: chromium-70.0.3538.110/ash/public/cpp/app_list/answer_card_contents_registry.h <==
// Copyright 2018 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef ASH_PUBLIC_CPP_APP_LIST_ANSWER_CARD_CONTENTS_REGISTRY_H_
#define ASH_PUBLIC_CPP_APP_LIST_ANSWER_CARD_CONTENTS_REGISTRY_H_

#include <map>

#include "ash/public/cpp/ash_public_export.h"
#include "base/macros.h"
#include "base/unguessable_token.h"
#include "ui/gfx/native_widget_types.h"

namespace views {
class View;
}

namespace app_list {

// Helper class to provide a token to answer card view map when app list UI code
// runs in the same process of answer card provider (classic ash, or mash before
// UI code is migrated to ash). In such environment, chrome creates and owns an
// instance of this class. AnswerCardContents registers answer card contents
// with it and get a token back. App list UI code gets the token and use it to
// look up the view to show. On mash after the UI code migration, this class
// will NOT be used at all. App list UI code would use the token to embed the
// answer card content directly.
class ASH_PUBLIC_EXPORT AnswerCardContentsRegistry {
 public:
  AnswerCardContentsRegistry();
  ~AnswerCardContentsRegistry();

  static AnswerCardContentsRegistry* Get();

  // Register content with a View and its relevant NativeView.
  base::UnguessableToken Register(views::View* contents_view,
                                  gfx::NativeView contents_native_view);

  // Unregister and release the associated resources.
  void Unregister(const base::UnguessableToken& token);

  // Get the view for the given token. Return nullptr for unknown token.
  views::View* GetView(const base::UnguessableToken& token);
  gfx::NativeView GetNativeView(const base::UnguessableToken& token);

 private:
  struct Entry {
    views::View* view;
    gfx::NativeView native_view;
  };

  std::map<base::UnguessableToken, Entry> contents_map_;

  DISALLOW_COPY_AND_ASSIGN(AnswerCardContentsRegistry);
};

}  // namespace app_list

#endif  // ASH_PUBLIC_CPP_APP_LIST_ANSWER_CARD_CONTENTS_REGISTRY_H_
